@@ -3,10 +3,11 @@ import wandio
 if __name__ == '__main__':
 
     files = [
-        'swift://datasets-external-netacq-codes/country_codes.csv',
-        'https://www.caida.org/~mingwei/',
-        'http://data.caida.org/datasets/as-relationships/README.txt',
-        'http://loki.caida.org:2243/data/external/as-rank-ribs/19980101/19980101.as-rel.txt.bz2'
+        # 'swift://datasets-external-netacq-codes/country_codes.csv',
+        # 'https://www.caida.org/~mingwei/',
+        # 'http://data.caida.org/datasets/as-relationships/README.txt',
+        # 'http://loki.caida.org:2243/data/external/as-rank-ribs/19980101/19980101.as-rel.txt.bz2',
+        '/home/mingwei/moas.1601006100.events.gz',
     ]
 
     for filename in files:
